# Read in data and open package
library(windex)
library(surface)
library(plotrix)
dat<-read.csv("J:\\PhD work\\Chemical vs ethomorphological defence study\\analysis files\\rwindexdata.csv",header=T)
rownames(dat)<-dat$species
tree<-read.tree("J:\\PhD work\\Chemical vs ethomorphological defence study\\analysis files\\butterflies.nwk")
timetree<-read.tree("J:\\PhD work\\Chemical vs ethomorphological defence study\\analysis files\\phylocomreltree.nwk")
timetree$node.label<-NULL
timetree$tip.label<-gsub("'","",timetree$tip.label)

# ASR of each of the 11 mimicry groups (plus all tiger morphs combined)
dione<-dat$dione
names(dione)<-rownames(dat)
dioneasr<-make.simmap(timetree,dione,model="ARD",nsim=1000)
dionemap<-densityMap(dioneasr)
plot(dionemap) # Not convergent - consists of two sister species

parides<-dat$parides
names(parides)<-rownames(dat)
paridesasr<-make.simmap(timetree,parides,model="ARD",nsim=1000)
paridesmap<-densityMap(paridesasr)
plot(paridesmap) # Not convergent? - estimated as repeatedly lost root state

tiger1<-dat$tiger1
names(tiger1)<-rownames(dat)
tiger1asr<-make.simmap(timetree,tiger1,model="ARD",nsim=1000)
tiger1map<-densityMap(tiger1asr)
plot(tiger1map) # Convergent - likely evolved 6-7 times

tiger2<-dat$tiger2
names(tiger2)<-rownames(dat)
tiger2asr<-make.simmap(timetree,tiger2,model="ARD",nsim=1000)
tiger2map<-densityMap(tiger2asr)
plot(tiger2map) # Convergent - likely evolved twice (both sister to tiger3)

tiger3<-dat$tiger3
names(tiger3)<-rownames(dat)
tiger3asr<-make.simmap(timetree,tiger3,model="ARD",nsim=1000)
tiger3map<-densityMap(tiger3asr)
plot(tiger3map) # Convergent - likely evolved twice (both sister to tiger2)

tiger4<-dat$tiger4
names(tiger4)<-rownames(dat)
tiger4asr<-make.simmap(timetree,tiger4,model="ARD",nsim=1000)
tiger4map<-densityMap(tiger4asr)
plot(tiger4map) # Convergent - likely evolved twice

tiger<-dat$tiger
names(tiger)<-rownames(dat)
tigerasr<-make.simmap(timetree,tiger,model="ARD",nsim=1000)
tigermap<-densityMap(tigerasr)
plot(tigermap) # Convergent - likely evolved ~8 times

oleria<-dat$oleria
names(oleria)<-rownames(dat)
oleriaasr<-make.simmap(timetree,oleria,model="ARD",nsim=1000)
oleriamap<-densityMap(oleriaasr)
plot(oleriamap) # Convergent - likely evolved twice

laodamia<-dat$laodamia
names(laodamia)<-rownames(dat)
laodamiaasr<-make.simmap(timetree,laodamia,model="ARD",nsim=1000)
laodamiamap<-densityMap(laodamiaasr)
plot(laodamiamap) # Not convergent - consists of two sister species

bw<-dat$bw
names(bw)<-rownames(dat)
bwasr<-make.simmap(timetree,bw,model="ARD",nsim=1000)
bwmap<-densityMap(bwasr)
plot(bwmap) # Convergent - likely evolved twice

byr<-dat$byr
names(byr)<-rownames(dat)
byrasr<-make.simmap(timetree,byr,model="ARD",nsim=1000)
byrmap<-densityMap(byrasr)
plot(byrmap) # Convergent - likely evolved twice

battus<-dat$battus
names(battus)<-rownames(dat)
battusasr<-make.simmap(timetree,battus,model="ARD",nsim=1000)
battusmap<-densityMap(battusasr)
plot(battusmap) # Convergent - likely evolved twice

# Fishers exact test of mimicry type versus convergence
mat<-matrix(c(2,2,7,2),nrow=2,dimnames=list(Convergent=c("Yes","No"),Mimicry=c("Batesian","Muellerian")))
fisher.test(mat) # P=0.53

# SURFACE analyses of each of the potentially convergent sets of variables
data<-data.frame(pal=dat$prop.pal,sp=dat$species)
rownames(data)<-dat$species
phy<-timetree
phy<-nameNodes(phy)
com<-comparative.data(phy,data,sp)
data<-data.frame(pal=com$data$pal)
rownames(data)<-rownames(com$data)
phy<-com$phy
s<-runSurface(phy,data)
palsum<-surfaceSummary(s$fwd,s$bwd)
palsum$n_regimes # Convergence - including 18 shifts to 4 convergent regimes
surfaceTreePlot(phy,s$bwd[[length(s$bwd)]],no.margin=T,show.tip.label=F,edge.width=3)
# In plot, black=0.97, red=0.03, green=0.43, blue=0.71, and purple=0.27

data<-data.frame(evas=dat$prop.fail,sp=dat$species)
rownames(data)<-dat$species
phy<-timetree
phy<-nameNodes(phy)
com<-comparative.data(phy,data,sp)
data<-data.frame(evas=com$data$evas)
rownames(data)<-rownames(com$data)
phy<-com$phy
s<-runSurface(phy,data)
evassum<-surfaceSummary(s$fwd,s$bwd)
evassum$n_regimes # Convergence - including 7 shifts to 3 convergent regimes
surfaceTreePlot(phy,s$bwd[[length(s$bwd)]],no.margin=T,show.tip.label=F,edge.width=3)
# In plot, black=0.29, red=-2.12, green=3.00, and blue=1.31

data<-data.frame(means=dat$mean.speed,maxs=dat$max.speed,sp=dat$species)
rownames(data)<-dat$species
phy<-timetree
phy<-nameNodes(phy)
com<-comparative.data(phy,data,sp)
data<-data.frame(means=com$data$means,maxs=com$data$maxs)
rownames(data)<-rownames(com$data)
phy<-com$phy
s<-runSurface(phy,data)
speedsum<-surfaceSummary(s$fwd,s$bwd)
speedsum$n_regimes # Convergence - including 12 shifts to 3 convergent regimes
surfaceTreePlot(phy,s$bwd[[length(s$bwd)]],no.margin=T,show.tip.label=F,edge.width=3)
# In plot, black=4.85, red=7.14, green=2.51, blue=4.08, and grey=5.43

data<-data.frame(bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter,sp=dat$species)
rownames(data)<-dat$species
phy<-timetree
phy<-nameNodes(phy)
com<-comparative.data(phy,data,sp)
data<-data.frame(bl=com$data$bl,bm=com$data$bm,rtl=com$data$rtl,rtm=com$data$rtm,ral=com$data$ral,ram=com$data$ram,td=com$data$td)
rownames(data)<-rownames(com$data)
phy<-com$phy
s<-runSurface(phy,data)
sizesum<-surfaceSummary(s$fwd,s$bwd)
sizesum$n_regimes # Convergence - including 10 shifts to 4 convergent regimes
surfaceTreePlot(phy,s$bwd[[length(s$bwd)]],no.margin=T,show.tip.label=F,edge.width=3)

data<-data.frame(wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase,sp=dat$species)
rownames(data)<-dat$species
phy<-timetree
phy<-nameNodes(phy)
com<-comparative.data(phy,data,sp)
data<-data.frame(wle=com$data$wle,wa=com$data$wa,ar=com$data$ar,wlo=com$data$wlo,wac=com$data$wac,wcom=com$data$wcom,rmi=com$data$rmi,bcomh=com$data$bcomh,bcomw=com$data$bcomw)
rownames(data)<-rownames(com$data)
phy<-com$phy
s<-runSurface(phy,data)
mechsum<-surfaceSummary(s$fwd,s$bwd)
mechsum$n_regimes # Convergence - including 6 shifts to 3 convergent regimes
surfaceTreePlot(phy,s$bwd[[length(s$bwd)]],no.margin=T,show.tip.label=F,edge.width=3)

##########################################################################

# Wheatsheaf indices for tiger1 group
tig1p<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,pal=dat$prop.pal)
rownames(tig1p)<-tig1$species
com<-comparative.data(timetree,tig1p,sp)
tig1pal<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

tig1e<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,evas=dat$prop.fail)
rownames(tig1e)<-tig1e$species
com<-comparative.data(timetree,tig1e,sp)
tig1evas<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

tig1sp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,means=dat$mean.speed,maxs=dat$max.speed)
rownames(tig1sp)<-tig1sp$species
com<-comparative.data(timetree,tig1sp,sp)
tig1speed<-windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T)

tig1bs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tig1bs)<-tig1bs$species
com<-comparative.data(timetree,tig1bs,sp)
tig1size<-windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T)

tig1mech<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(tig1mech)<-tig1mech$species
com<-comparative.data(timetree,tig1mech,sp)
tig1mech<-windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T)

qtig1<-data.frame(cats=c("Pal","Evas","Speed","Size","Biomech"),w=c(tig1pal$"Wheatsheaf Index",tig1evas$"Wheatsheaf Index",tig1speed$"Wheatsheaf Index",tig1size$"Wheatsheaf Index",tig1mech$"Wheatsheaf Index"),l95=c(tig1pal$"Lower 95% CI",tig1evas$"Lower 95% CI",tig1speed$"Lower 95% CI",tig1size$"Lower 95% CI",tig1mech$"Lower 95% CI"),u95=c(tig1pal$"Upper 95% CI",tig1evas$"Upper 95% CI",tig1speed$"Upper 95% CI",tig1size$"Upper 95% CI",tig1mech$"Upper 95% CI"))
rownames(qtig1)<-qtig1$cats
or<-order(qtig1$cats)
qtig12<-qtig1[or,]
plotCI(qtig12$w,ui=qtig12$u95,li=qtig12$l95,add=F,xaxt="n",xlab="Trait sets (Tiger1)",ylab="Wheatsheaf index",pch=19,pt.bg="black")
axis(1,at=1:5,labels=qtig12$cats)

# Wheatsheaf indices for tiger2 group
tig2p<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger2,pal=dat$prop.pal)
rownames(tig2p)<-tig2p$species
com<-comparative.data(timetree,tig2p,sp)
tig2pal<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

tig2e<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger2,evas=dat$prop.fail)
rownames(tig2e)<-tig2e$species
com<-comparative.data(timetree,tig2e,sp)
tig2evas<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

#tig2sp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger2,means=dat$mean.speed,maxs=dat$max.speed)
#rownames(tig2sp)<-tig2sp$species
#com<-comparative.data(timetree,tig2sp,sp)
#tig2speed<-windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T)
# Excluded as there is no data for speed of both members of mimicry group.

tig2bs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger2,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tig2bs)<-tig2bs$species
com<-comparative.data(timetree,tig2bs,sp)
tig2size<-windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T)

tig2mech<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger2,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(tig2mech)<-tig2mech$species
com<-comparative.data(timetree,tig2mech,sp)
tig2mech<-windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T)

qtig2<-data.frame(cats=c("Pal","Evas","Size","Biomech"),w=c(tig2pal$"Wheatsheaf Index",tig2evas$"Wheatsheaf Index",tig2size$"Wheatsheaf Index",tig2mech$"Wheatsheaf Index"),l95=c(tig2pal$"Lower 95% CI",tig2evas$"Lower 95% CI",tig2size$"Lower 95% CI",tig2mech$"Lower 95% CI"),u95=c(tig2pal$"Upper 95% CI",tig2evas$"Upper 95% CI",tig2size$"Upper 95% CI",tig2mech$"Upper 95% CI"))
rownames(qtig2)<-qtig2$cats
or<-order(qtig2$cats)
qtig22<-qtig2[or,]
plotCI(qtig22$w,ui=qtig22$u95,li=qtig22$l95,add=F,xaxt="n",xlab="Trait sets (Tiger2)",ylab="Wheatsheaf index",pch=19,pt.bg="black")
axis(1,at=1:4,labels=qtig22$cats)

# Wheatsheaf indices for tiger3 group
tig3p<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,pal=dat$prop.pal)
rownames(tig3p)<-tig3p$species
com<-comparative.data(timetree,tig3p,sp)
tig3pal<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

tig3e<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,evas=dat$prop.fail)
rownames(tig3e)<-tig3e$species
com<-comparative.data(timetree,tig3e,sp)
tig3evas<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

tig3sp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,means=dat$mean.speed,maxs=dat$max.speed)
rownames(tig3sp)<-tig3sp$species
com<-comparative.data(timetree,tig3sp,sp)
tig3speed<-windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T)

tig3bs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tig3bs)<-tig3bs$species
com<-comparative.data(timetree,tig3bs,sp)
tig3size<-windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T)

tig3mech<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(tig3mech)<-tig3mech$species
com<-comparative.data(timetree,tig3mech,sp)
tig3mech<-windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T)

qtig3<-data.frame(cats=c("Pal","Evas","Speed","Size","Biomech"),w=c(tig3pal$"Wheatsheaf Index",tig3evas$"Wheatsheaf Index",tig3speed$"Wheatsheaf Index",tig3size$"Wheatsheaf Index",tig3mech$"Wheatsheaf Index"),l95=c(tig3pal$"Lower 95% CI",tig3evas$"Lower 95% CI",tig3speed$"Lower 95% CI",tig3size$"Lower 95% CI",tig3mech$"Lower 95% CI"),u95=c(tig3pal$"Upper 95% CI",tig3evas$"Upper 95% CI",tig3speed$"Upper 95% CI",tig3size$"Upper 95% CI",tig3mech$"Upper 95% CI"))
rownames(qtig3)<-qtig3$cats
or<-order(qtig3$cats)
qtig32<-qtig3[or,]
plotCI(qtig32$w,ui=qtig32$u95,li=qtig32$l95,add=F,xaxt="n",xlab="Trait sets (Tiger3)",ylab="Wheatsheaf index",pch=19,pt.bg="black")
axis(1,at=1:5,labels=qtig32$cats)

# Wheatsheaf indices for tiger4 group
#tig4p<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger4,pal=tempdat$prop.pal)
#rownames(tig4p)<-tig4p$species
#com<-comparative.data(timetree,tig4p,sp)
#tig4pal<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)
# Excluded as the two mimics both have values of 0 (so probably convergent but mathematically intractable).

tig4e<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger4,evas=dat$prop.fail)
rownames(tig4e)<-tig4e$species
com<-comparative.data(timetree,tig4e,sp)
tig4evas<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

#tig4sp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger4,means=dat$mean.speed,maxs=dat$max.speed)
#rownames(tig4sp)<-tig4sp$species
#com<-comparative.data(timetree,tig4sp,sp)
#tig4speed<-windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T)
# Excluded as there is no data for speed of any members of mimicry group.

tig4bs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger4,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tig4bs)<-tig4bs$species
com<-comparative.data(timetree,tig4bs,sp)
tig4size<-windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T)

#tig4mech<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger4,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
#rownames(tig4mech)<-tig4mech$species
#com<-comparative.data(timetree,tig4mech,sp)
#tig4mech<-windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T)
# Excluded as there is no data for speed of any members of mimicry group.

qtig4<-data.frame(cats=c("Evas","Size"),w=c(tig4evas$"Wheatsheaf Index",tig4size$"Wheatsheaf Index"),l95=c(tig4evas$"Lower 95% CI",tig4size$"Lower 95% CI"),u95=c(tig4evas$"Upper 95% CI",tig4size$"Upper 95% CI"))
rownames(qtig4)<-qtig4$cats
or<-order(qtig4$cats)
qtig42<-qtig4[or,]
plotCI(qtig42$w,ui=qtig42$u95,li=qtig42$l95,add=F,xaxt="n",xlab="Trait sets (Tiger4)",ylab="Wheatsheaf index",pch=19,pt.bg="black")
axis(1,at=1:2,labels=qtig42$cats)

# Wheatsheaf indices for tiger groups combined
tigp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,pal=dat$prop.pal)
rownames(tigp)<-tigp$species
com<-comparative.data(timetree,tigp,sp)
tigpal<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

tige<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,evas=dat$prop.fail)
rownames(tige)<-tige$species
com<-comparative.data(timetree,tige,sp)
tigevas<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

tigsp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,means=dat$mean.speed,maxs=dat$max.speed)
rownames(tigsp)<-tigsp$species
com<-comparative.data(timetree,tigsp,sp)
tigspeed<-windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T)

tigbs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tigbs)<-tigbs$species
com<-comparative.data(timetree,tigbs,sp)
tigsize<-windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T)

tigmech<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(tigmech)<-tigmech$species
com<-comparative.data(timetree,tigmech,sp)
tigmech<-windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T)

qtig<-data.frame(cats=c("Pal","Evas","Speed","Size","Biomech"),w=c(tigpal$"Wheatsheaf Index",tigevas$"Wheatsheaf Index",tigspeed$"Wheatsheaf Index",tigsize$"Wheatsheaf Index",tigmech$"Wheatsheaf Index"),l95=c(tigpal$"Lower 95% CI",tigevas$"Lower 95% CI",tigspeed$"Lower 95% CI",tigsize$"Lower 95% CI",tigmech$"Lower 95% CI"),u95=c(tigpal$"Upper 95% CI",tigevas$"Upper 95% CI",tigspeed$"Upper 95% CI",tigsize$"Upper 95% CI",tigmech$"Upper 95% CI"))
rownames(qtig)<-qtig$cats
or<-order(qtig$cats)
qtigc2<-qtig[or,]
plotCI(qtigc2$w,ui=qtigc2$u95,li=qtigc2$l95,add=F,xaxt="n",xlab="Trait sets (Tiger morphs combined)",ylab="Wheatsheaf index",pch=19,pt.bg="black")
axis(1,at=1:5,labels=qtigc2$cats)

# Wheatsheaf indices for oleria group
oleriap<-data.frame(sp=dat$species,species=dat$species,foc=dat$oleria,pal=dat$prop.pal)
rownames(oleriap)<-oleriap$species
com<-comparative.data(timetree,oleriap,sp)
oleriapal<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

#oleriae<-data.frame(sp=dat$species,species=dat$species,foc=dat$oleria,evas=dat$prop.fail)
#rownames(oleriae)<-oleriae$species
#com<-comparative.data(timetree,oleriae,sp)
#oleriaevas<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)
# Excluded as the two mimics both have values of 0 (so probably convergent but mathematically intractable).

#oleriasp<-data.frame(sp=dat$species,species=dat$species,foc=dat$oleria,means=dat$mean.speed,maxs=dat$max.speed)
#rownames(oleriasp)<-oleriasp$species
#com<-comparative.data(timetree,oleriasp,sp)
#oleriaspeed<-windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T)
# Excluded as there is no data for speed of any members of mimicry group.

oleriabs<-data.frame(sp=dat$species,species=dat$species,foc=dat$oleria,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(oleriabs)<-oleriabs$species
com<-comparative.data(timetree,oleriabs,sp)
oleriasize<-windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T)

oleriamech<-data.frame(sp=dat$species,species=dat$species,foc=dat$oleria,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(oleriamech)<-oleriamech$species
com<-comparative.data(timetree,oleriamech,sp)
oleriamech<-windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T)

qoleria<-data.frame(cats=c("Pal","Size","Biomech"),w=c(oleriapal$"Wheatsheaf Index",oleriasize$"Wheatsheaf Index",oleriamech$"Wheatsheaf Index"),l95=c(oleriapal$"Lower 95% CI",oleriasize$"Lower 95% CI",oleriamech$"Lower 95% CI"),u95=c(oleriapal$"Upper 95% CI",oleriasize$"Upper 95% CI",oleriamech$"Upper 95% CI"))
rownames(qoleria)<-qoleria$cats
or<-order(qoleria$cats)
qoleria2<-qoleria[or,]
plotCI(qoleria2$w,ui=qoleria2$u95,li=qoleria2$l95,add=F,xaxt="n",xlab="Trait sets (Oleria)",ylab="Wheatsheaf index",pch=19,pt.bg="black")
axis(1,at=1:3,labels=qoleria2$cats)

# Wheatsheaf indices for black-white group
#bwp<-data.frame(sp=dat$species,species=dat$species,foc=dat$bw,pal=dat$prop.pal)
#rownames(bwp)<-bwp$species
#com<-comparative.data(timetree,bwp,sp)
#bwpal<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)
# Excluded as the two mimics both have values of 0 (so probably convergent but mathematically intractable).

bwe<-data.frame(sp=dat$species,species=dat$species,foc=dat$bw,evas=dat$prop.fail)
rownames(bwe)<-bwe$species
com<-comparative.data(timetree,bwe,sp)
bwevas<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

bwsp<-data.frame(sp=dat$species,species=dat$species,foc=dat$bw,means=dat$mean.speed,maxs=dat$max.speed)
rownames(bwsp)<-bwsp$species
com<-comparative.data(timetree,bwsp,sp)
bwspeed<-windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T)

bwbs<-data.frame(sp=dat$species,species=dat$species,foc=dat$bw,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(bwbs)<-bwbs$species
com<-comparative.data(timetree,bwbs,sp)
bwsize<-windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T)

bwmech<-data.frame(sp=dat$species,species=dat$species,foc=dat$bw,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(bwmech)<-bwmech$species
com<-comparative.data(timetree,bwmech,sp)
bwmech<-windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T)

qbw<-data.frame(cats=c("Evas","Speed","Size","Biomech"),w=c(bwevas$"Wheatsheaf Index",bwspeed$"Wheatsheaf Index",bwsize$"Wheatsheaf Index",bwmech$"Wheatsheaf Index"),l95=c(bwevas$"Lower 95% CI",bwspeed$"Lower 95% CI",bwsize$"Lower 95% CI",bwmech$"Lower 95% CI"),u95=c(bwevas$"Upper 95% CI",bwspeed$"Upper 95% CI",bwsize$"Upper 95% CI",bwmech$"Upper 95% CI"))
rownames(qbw)<-qbw$cats
or<-order(qbw$cats)
qbw2<-qbw[or,]
plotCI(qbw2$w,ui=qbw2$u95,li=qbw2$l95,add=F,xaxt="n",xlab="Trait sets (Black-white)",ylab="Wheatsheaf index",pch=19,pt.bg="black")
axis(1,at=1:4,labels=qbw2$cats)

# Wheatsheaf indices for black-yellow-red group
byrp<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,pal=dat$prop.pal)
rownames(byrp)<-byrp$species
com<-comparative.data(timetree,byrp,sp)
byrpal<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

byre<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,evas=dat$prop.fail)
rownames(byre)<-byre$species
com<-comparative.data(timetree,byre,sp)
byrevas<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

byrsp<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,means=dat$mean.speed,maxs=dat$max.speed)
rownames(byrsp)<-byrsp$species
com<-comparative.data(timetree,byrsp,sp)
byrspeed<-windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T)

byrbs<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(byrbs)<-byrbs$species
com<-comparative.data(timetree,byrbs,sp)
byrsize<-windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T)

byrmech<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(byrmech)<-byrmech$species
com<-comparative.data(timetree,byrmech,sp)
byrmech<-windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T)

qbyr<-data.frame(cats=c("Pal","Evas","Speed","Size","Biomech"),w=c(byrpal$"Wheatsheaf Index",byrevas$"Wheatsheaf Index",byrspeed$"Wheatsheaf Index",byrsize$"Wheatsheaf Index",byrmech$"Wheatsheaf Index"),l95=c(byrpal$"Lower 95% CI",byrevas$"Lower 95% CI",byrspeed$"Lower 95% CI",byrsize$"Lower 95% CI",byrmech$"Lower 95% CI"),u95=c(byrpal$"Upper 95% CI",byrevas$"Upper 95% CI",byrspeed$"Upper 95% CI",byrsize$"Upper 95% CI",byrmech$"Upper 95% CI"))
rownames(qbyr)<-qbyr$cats
or<-order(qbyr$cats)
qbyr2<-qbyr[or,]
plotCI(qbyr2$w,ui=qbyr2$u95,li=qbyr2$l95,add=F,xaxt="n",xlab="Trait sets (Black-yellow-red)",ylab="Wheatsheaf index",pch=19,pt.bg="black")
axis(1,at=1:5,labels=qbyr2$cats)

# Wheatsheaf indices for Battus group
battusp<-data.frame(sp=dat$species,species=dat$species,foc=dat$battus,pal=dat$prop.pal)
rownames(battusp)<-battusp$species
com<-comparative.data(timetree,battusp,sp)
battuspal<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

battuse<-data.frame(sp=dat$species,species=dat$species,foc=dat$battus,evas=dat$prop.fail)
rownames(battuse)<-battuse$species
com<-comparative.data(timetree,battuse,sp)
battusevas<-windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T)

#battussp<-data.frame(sp=dat$species,species=dat$species,foc=dat$battus,means=dat$mean.speed,maxs=dat$max.speed)
#rownames(battussp)<-battussp$species
#com<-comparative.data(timetree,battussp,sp)
#battusspeed<-windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T)
# Excluded as there is no data for speed of both members of mimicry group.

battusbs<-data.frame(sp=dat$species,species=dat$species,foc=dat$battus,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(battusbs)<-battusbs$species
com<-comparative.data(timetree,battusbs,sp)
battussize<-windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T)

battusmech<-data.frame(sp=dat$species,species=dat$species,foc=dat$battus,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(battusmech)<-battusmech$species
com<-comparative.data(timetree,battusmech,sp)
battusmech<-windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T)
# Excluded as there is incomplete data for both members of mimicry group.

qbattus<-data.frame(cats=c("Pal","Evas","Size"),w=c(battuspal$"Wheatsheaf Index",battusevas$"Wheatsheaf Index",battussize$"Wheatsheaf Index"),l95=c(battuspal$"Lower 95% CI",battusevas$"Lower 95% CI",battussize$"Lower 95% CI"),u95=c(battuspal$"Upper 95% CI",battusevas$"Upper 95% CI",battussize$"Upper 95% CI"))
rownames(qbattus)<-qbattus$cats
or<-order(qbattus$cats)
qbattus2<-qbattus[or,]
plotCI(qbattus2$w,ui=qbattus2$u95,li=qbattus2$l95,add=F,xaxt="n",xlab="Trait sets (Battus)",ylab="Wheatsheaf index",pch=19,pt.bg="black")
axis(1,at=1:3,labels=qbattus2$cats)

#############################################################################
# P-values from Wheatsheaf analyses
nomen<-c()
p<-c()
tig1p<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,pal=dat$prop.pal)
rownames(tig1p)<-tig1$species
com<-comparative.data(timetree,tig1p,sp)
p[1]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[1]<-"tig1pal"

tig1e<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,evas=dat$prop.fail)
rownames(tig1e)<-tig1e$species
com<-comparative.data(timetree,tig1e,sp)
p[2]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[2]<-"tig1evas"

tig1sp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,means=dat$mean.speed,maxs=dat$max.speed)
rownames(tig1sp)<-tig1sp$species
com<-comparative.data(timetree,tig1sp,sp)
p[3]<-test.windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[3]<-"tig1speed"

tig1bs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tig1bs)<-tig1bs$species
com<-comparative.data(timetree,tig1bs,sp)
p[4]<-test.windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[4]<-"tig1size"

tig1mech<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger1,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(tig1mech)<-tig1mech$species
com<-comparative.data(timetree,tig1mech,sp)
p[5]<-test.windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[5]<-"tig1mech"

tig2p<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger2,pal=dat$prop.pal)
rownames(tig2p)<-tig2p$species
com<-comparative.data(timetree,tig2p,sp)
p[6]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[6]<-"tig2pal"

tig2e<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger2,evas=dat$prop.fail)
rownames(tig2e)<-tig2e$species
com<-comparative.data(timetree,tig2e,sp)
p[7]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[7]<-"tig2evas"

tig2bs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger2,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tig2bs)<-tig2bs$species
com<-comparative.data(timetree,tig2bs,sp)
p[8]<-test.windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[8]<-"tig2size"

tig2mech<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger2,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(tig2mech)<-tig2mech$species
com<-comparative.data(timetree,tig2mech,sp)
p[9]<-test.windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[9]<-"tig2mech"

tig3p<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,pal=dat$prop.pal)
rownames(tig3p)<-tig3p$species
com<-comparative.data(timetree,tig3p,sp)
p[10]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[10]<-"tig3pal"

tig3e<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,evas=dat$prop.fail)
rownames(tig3e)<-tig3e$species
com<-comparative.data(timetree,tig3e,sp)
p[11]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[11]<-"tig3evas"

tig3sp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,means=dat$mean.speed,maxs=dat$max.speed)
rownames(tig3sp)<-tig3sp$species
com<-comparative.data(timetree,tig3sp,sp)
p[12]<-test.windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[12]<-"tig3speed"

tig3bs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tig3bs)<-tig3bs$species
com<-comparative.data(timetree,tig3bs,sp)
p[13]<-test.windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[13]<-"tig3size"

tig3mech<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger3,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(tig3mech)<-tig3mech$species
com<-comparative.data(timetree,tig3mech,sp)
p[14]<-test.windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[14]<-"tig3mech"

tig4e<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger4,evas=dat$prop.fail)
rownames(tig4e)<-tig4e$species
com<-comparative.data(timetree,tig4e,sp)
p[15]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[15]<-"tig4evas"

tig4bs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger4,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tig4bs)<-tig4bs$species
com<-comparative.data(timetree,tig4bs,sp)
p[16]<-test.windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[16]<-"tig4size"

tigp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,pal=dat$prop.pal)
rownames(tigp)<-tigp$species
com<-comparative.data(timetree,tigp,sp)
p[17]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[17]<-"tigpal"

tige<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,evas=dat$prop.fail)
rownames(tige)<-tige$species
com<-comparative.data(timetree,tige,sp)
p[18]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[18]<-"tigevas"

tigsp<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,means=dat$mean.speed,maxs=dat$max.speed)
rownames(tigsp)<-tigsp$species
com<-comparative.data(timetree,tigsp,sp)
p[19]<-test.windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[19]<-"tigspeed"

tigbs<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(tigbs)<-tigbs$species
com<-comparative.data(timetree,tigbs,sp)
p[20]<-test.windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[20]<-"tigsize"

tigmech<-data.frame(sp=dat$species,species=dat$species,foc=dat$tiger,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(tigmech)<-tigmech$species
com<-comparative.data(timetree,tigmech,sp)
p[21]<-test.windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[21]<-"tigmech"

oleriap<-data.frame(sp=dat$species,species=dat$species,foc=dat$oleria,pal=dat$prop.pal)
rownames(oleriap)<-oleriap$species
com<-comparative.data(timetree,oleriap,sp)
p[22]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[22]<-"oleriapal"

oleriabs<-data.frame(sp=dat$species,species=dat$species,foc=dat$oleria,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(oleriabs)<-oleriabs$species
com<-comparative.data(timetree,oleriabs,sp)
p[23]<-test.windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[23]<-"oleriasize"

oleriamech<-data.frame(sp=dat$species,species=dat$species,foc=dat$oleria,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(oleriamech)<-oleriamech$species
com<-comparative.data(timetree,oleriamech,sp)
p[24]<-test.windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[24]<-"oleriamech"

bwe<-data.frame(sp=dat$species,species=dat$species,foc=dat$bw,evas=dat$prop.fail)
rownames(bwe)<-bwe$species
com<-comparative.data(timetree,bwe,sp)
p[25]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[25]<-"bwevas"

bwsp<-data.frame(sp=dat$species,species=dat$species,foc=dat$bw,means=dat$mean.speed,maxs=dat$max.speed)
rownames(bwsp)<-bwsp$species
com<-comparative.data(timetree,bwsp,sp)
p[26]<-test.windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[26]<-"bwspeed"

bwbs<-data.frame(sp=dat$species,species=dat$species,foc=dat$bw,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(bwbs)<-bwbs$species
com<-comparative.data(timetree,bwbs,sp)
p[27]<-test.windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[27]<-"bwsize"

bwmech<-data.frame(sp=dat$species,species=dat$species,foc=dat$bw,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(bwmech)<-bwmech$species
com<-comparative.data(timetree,bwmech,sp)
p[28]<-test.windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[28]<-"bwmech"

byrp<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,pal=dat$prop.pal)
rownames(byrp)<-byrp$species
com<-comparative.data(timetree,byrp,sp)
p[29]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[29]<-"byrpal"

byre<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,evas=dat$prop.fail)
rownames(byre)<-byre$species
com<-comparative.data(timetree,byre,sp)
p[30]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[30]<-"byrevas"

byrsp<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,means=dat$mean.speed,maxs=dat$max.speed)
rownames(byrsp)<-byrsp$species
com<-comparative.data(timetree,byrsp,sp)
p[31]<-test.windex(com$data,com$phy,traits=c(3,4),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[31]<-"byrspeed"

byrbs<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(byrbs)<-byrbs$species
com<-comparative.data(timetree,byrbs,sp)
p[32]<-test.windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[32]<-"byrsize"

byrmech<-data.frame(sp=dat$species,species=dat$species,foc=dat$byr,wle=dat$wing.length,wa=dat$wing.area,ar=dat$aspect.ratio,wlo=dat$wing.loading,wac=dat$wing.area.centroid,wcom=dat$wing.centre.of.mass,rmi=dat$radial.moment.of.inertia,bcomh=dat$body.centre.of.mass.head,bcomw=dat$body.centre.of.mass.wingbase)
rownames(byrmech)<-byrmech$species
com<-comparative.data(timetree,byrmech,sp)
p[33]<-test.windex(com$data,com$phy,traits=c(3:11),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[33]<-"byrmech"

battusp<-data.frame(sp=dat$species,species=dat$species,foc=dat$battus,pal=dat$prop.pal)
rownames(battusp)<-battusp$species
com<-comparative.data(timetree,battusp,sp)
p[34]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[34]<-"battuspal"

battuse<-data.frame(sp=dat$species,species=dat$species,foc=dat$battus,evas=dat$prop.fail)
rownames(battuse)<-battuse$species
com<-comparative.data(timetree,battuse,sp)
p[35]<-test.windex(com$data,com$phy,traits=3,focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[35]<-"battusevas"

battusbs<-data.frame(sp=dat$species,species=dat$species,foc=dat$battus,bl=dat$body.length,bm=dat$body.mass,rtl=(dat$thorax.length/dat$body.length),rtm=(dat$thorax.mass/dat$body.mass),ral=(dat$abdomen.length/dat$body.length),ram=(dat$abdomen.mass/dat$body.mass),td=dat$thorax.diameter)
rownames(battusbs)<-battusbs$species
com<-comparative.data(timetree,battusbs,sp)
p[36]<-test.windex(com$data,com$phy,traits=c(3:9),focal=com$data[,2],SE=T,reps=1000,plot=F)$"P-value="
nomen[36]<-"battussize"

tests<-data.frame(P=p)
rownames(tests)<-nomen
tests
write.csv(tests,"J:\\PhD work\\Chemical vs ethomorphological defence study\\windex tests.csv")

